try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},o=(new e.Error).stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="a4decb08-604d-43e3-9789-826bec9f9840",e._sentryDebugIdIdentifier="sentry-dbid-a4decb08-604d-43e3-9789-826bec9f9840")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.09-0afadcc"}}catch(e){}}(),exports.id=973,exports.ids=[973],exports.modules={"./src/commands/worker-pool.ts":(e,o,n)=>{n.r(o),n.d(o,{DEFAULT_WORKER_POOL_NAME:()=>t,WORKER_POOL_LABEL_KEY:()=>l,applyWorkerPoolLabel:()=>r,getWorkerPoolName:()=>s,isPoolAssignmentEnabled:()=>d,resolveWorkerPoolName:()=>i});const l="pool",t="default";function d(e){return!0===e.pool||!0===e.singleUse}function i(e){var o;const n=null===(o=e.poolName)||void 0===o?void 0:o.trim();if(void 0!==e.poolName&&(!n||0===n.length))throw new Error("--pool-name cannot be empty");if(e.poolAssignmentEnabled)return null!=n?n:t;if(void 0!==n)throw new Error("--pool-name requires --pool or --single-use")}function r(e,o){return o?[{key:l,value:o},...e.filter((e=>e.key!==l))]:[...e]}function s(e){const o=null==e?void 0:e.find((e=>e.key===l)),n=null==o?void 0:o.value.trim();return n&&n.length>0?n:void 0}}};