try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9a20b53d-99f3-4983-9ad2-eadb80ec2a16",e._sentryDebugIdIdentifier="sentry-dbid-9a20b53d-99f3-4983-9ad2-eadb80ec2a16")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.09-0afadcc"}}catch(e){}}(),exports.id=9864,exports.ids=[9864],exports.modules={"./src/commands/get-channel.ts":(e,n,d)=>{function t(e){const n=e.get();n.channel&&process.stdout.write(`${n.channel}\n`),process.exit(0)}d.r(n),d.d(n,{handleGetChannel:()=>t})}};