try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="8ef102e1-05f8-47ad-85c0-d3f1fffb132c",e._sentryDebugIdIdentifier="sentry-dbid-8ef102e1-05f8-47ad-85c0-d3f1fffb132c")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.09-0afadcc"}}catch(e){}}(),exports.id=7735,exports.ids=[7735],exports.modules={"./src/commands/repo-info.tsx":(e,n,o)=>{o.r(n),o.d(n,{handleRepoInfo:()=>i});var t=o("./src/console-io.ts"),f=function(e,n,o,t){return new(o||(o=Promise))((function(f,i){function d(e){try{r(t.next(e))}catch(e){i(e)}}function s(e){try{r(t.throw(e))}catch(e){i(e)}}function r(e){var n;e.done?f(e.value):(n=e.value,n instanceof o?n:new o((function(e){e(n)}))).then(d,s)}r((t=t.apply(e,n||[])).next())}))};function i(e){return f(this,void 0,void 0,(function*(){try{const n=yield e.getRepositoryInfo();(0,t.OT)(JSON.stringify(n,null,2))}catch(e){(0,t.p2)(e instanceof Error?e.message:String(e))}process.exit(0)}))}}};