try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},s=(new e.Error).stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="e68d6fec-6228-4a01-8a18-d0e7ccd9b242",e._sentryDebugIdIdentifier="sentry-dbid-e68d6fec-6228-4a01-8a18-d0e7ccd9b242")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.09-0afadcc"}}catch(e){}}(),exports.id=3066,exports.ids=[3066],exports.modules={"./src/commands/auth-status-format.ts":(e,s,n)=>{n.d(s,{$7:()=>r,Fg:()=>o,cq:()=>c});var t=n("../../node_modules/.pnpm/chalk@5.4.1/node_modules/chalk/source/index.js");function o(e){const{status:s,message:n,userInfo:o,loginUrl:c}=e;switch(s){case"starting":return"Starting login process...";case"in-progress":{const e=["Authenticating with Cursor..."];return n&&e.push(n),c&&e.push(t.Ay.dim(c)),e.join("\n")}case"success":{const e=(null==o?void 0:o.email)?`Logged in as ${o.email}`:(null==o?void 0:o.userId)?`Logged in as user id ${o.userId}`:"Login successful!",s=[`${t.Ay.green("✓")} ${e}`];return n&&s.push(n),s.join("\n")}case"error":return n?t.Ay.red(n):""}}function c(e){const{status:s,message:n}=e;switch(s){case"starting":return"Preparing to log out...";case"in-progress":return"Logging out...";case"success":{const e=[t.Ay.green("✓ Logout successful")];return n&&e.push(n),e.join("\n")}case"error":{const e=[t.Ay.red("✗ Logout failed")];return n&&e.push(t.Ay.red(n)),e.join("\n")}}}function r(e){const{status:s,message:n}=e;switch(s){case"starting":{const e=["MCP Login","Preparing login..."];return n&&e.push(n),e.join("\n")}case"in-progress":{const e=["Checking status..."];return n&&e.push(n),e.join("\n")}case"success":{const e=[t.Ay.green("✓ MCP login successful")];return n&&e.push(n),e.join("\n")}case"error":{const e=[t.Ay.red("✗ MCP login failed")];return n&&e.push(t.Ay.red(n)),e.join("\n")}}}},"./src/commands/logout.ts":(e,s,n)=>{n.r(s),n.d(s,{handleLogout:()=>a});var t=n("../keychain/dist/index.js"),o=n("./src/console-io.ts"),c=n("./src/statsig.ts"),r=n("./src/commands/auth-status-format.ts"),i=function(e,s,n,t){return new(n||(n=Promise))((function(o,c){function r(e){try{a(t.next(e))}catch(e){c(e)}}function i(e){try{a(t.throw(e))}catch(e){c(e)}}function a(e){var s;e.done?o(e.value):(s=e.value,s instanceof n?s:new n((function(e){e(s)}))).then(r,i)}a((t=t.apply(e,s||[])).next())}))};function a(e,s){return i(this,void 0,void 0,(function*(){(0,o.OT)((0,r.cq)({status:"starting"}));try{(yield e.getAccessToken())||((0,o.OT)((0,r.cq)({status:"success",message:"Authentication tokens removed."})),process.exit(0))}catch(e){e instanceof t.fI&&((0,o.OT)((0,r.cq)({status:"success",message:"Authentication tokens removed."})),process.exit(0))}try{(0,o.OT)((0,r.cq)({status:"in-progress"})),yield e.clearAuthentication(),yield s.transform((e=>Object.assign(Object.assign({},e),{privacyCache:void 0,authInfo:void 0}))),(0,c.yX)(),(0,o.OT)((0,r.cq)({status:"success",message:"Authentication tokens removed."}))}catch(e){(0,o.p2)((0,r.cq)({status:"error",message:`Failed to remove authentication tokens: ${e}`})),process.exit(1)}process.exit(0)}))}}};