try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="7e259a74-4eaf-4935-9c9e-69d8e821821d",e._sentryDebugIdIdentifier="sentry-dbid-7e259a74-4eaf-4935-9c9e-69d8e821821d")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.09-0afadcc"}}catch(e){}}(),exports.id=1832,exports.ids=[1832],exports.modules={"./src/commands/sandbox-config.ts":(e,n,s)=>{s.r(n),s.d(n,{handleSandboxDisable:()=>c,handleSandboxEnable:()=>b,handleSandboxReset:()=>l});var o=s("../shell-exec/dist/index.js"),t=s("./src/console-io.ts"),a=s("./src/sandbox-gate.ts"),i=s("./src/utils/sandbox-messages.ts"),d=function(e,n,s,o){return new(s||(s=Promise))((function(t,a){function i(e){try{r(o.next(e))}catch(e){a(e)}}function d(e){try{r(o.throw(e))}catch(e){a(e)}}function r(e){var n;e.done?t(e.value):(n=e.value,n instanceof s?n:new s((function(e){e(n)}))).then(i,d)}r((o=o.apply(e,n||[])).next())}))},r=function(e,n){var s={};for(var o in e)Object.prototype.hasOwnProperty.call(e,o)&&n.indexOf(o)<0&&(s[o]=e[o]);if(null!=e&&"function"==typeof Object.getOwnPropertySymbols){var t=0;for(o=Object.getOwnPropertySymbols(e);t<o.length;t++)n.indexOf(o[t])<0&&Object.prototype.propertyIsEnumerable.call(e,o[t])&&(s[o[t]]=e[o[t]])}return s};function b(e){return d(this,void 0,void 0,(function*(){(0,a.Y)()&&(0,o.K3)()||(yield e.transform((e=>Object.assign(Object.assign({},e),{sandbox:Object.assign(Object.assign({},e.sandbox),{mode:"disabled"})}))),(0,t.OT)(`Error: Sandbox is not available on this system. ${(0,i.l)()}.`),process.exit(1)),yield e.transform((e=>Object.assign(Object.assign({},e),{sandbox:Object.assign(Object.assign({},e.sandbox),{mode:"enabled"})}))),(0,t.OT)("✅ Sandbox mode enabled. Commands will now run in a sandbox environment."),(0,t.OT)("💡 Use 'agent sandbox disable' to switch back to allowlist mode."),process.exit(0)}))}function c(e){return d(this,void 0,void 0,(function*(){yield e.transform((e=>Object.assign(Object.assign({},e),{sandbox:Object.assign(Object.assign({},e.sandbox),{mode:"disabled"})}))),(0,t.OT)("✅ Sandbox mode disabled. Commands will now use allowlist mode (default)."),(0,t.OT)("💡 Use 'agent sandbox enable' to switch back to sandbox mode."),process.exit(0)}))}function l(e){return d(this,void 0,void 0,(function*(){yield e.transform((e=>{const{sandbox:n}=e,s=r(e,["sandbox"]);return Object.assign(Object.assign({},s),{showSandboxIntro:!0})})),(0,t.OT)("✅ Sandbox configuration reset. All sandbox-specific settings have been removed."),(0,t.OT)("💡 Use 'agent sandbox enable' to configure sandbox mode again."),process.exit(0)}))}},"./src/sandbox-gate.ts":(e,n,s)=>{s.d(n,{Y:()=>r});var o=s("./src/statsig.ts");const t="composer_sandbox_settings_visible",a="sandbox_force_disable_linux",i="sandbox_force_disable_win32";function d(e,n){return(0,o.mD)()?(0,o.QF)(e):n}function r(e="darwin"){return!(!d(t,!0)||"linux"===e&&d(a,!1)||"win32"===e&&d(i,!0))}},"./src/utils/sandbox-messages.ts":(e,n,s)=>{function o(){return"Sandbox is unavailable"}s.d(n,{l:()=>o}),s("node:os")}};